@@ -19,10 +19,21 @@ case "${PLUGIN_VERSION}" in
         HADOOP_VERSION="2.7.1"
         BUILD_ARGS="-Puber -P hadoop-2"
     ;;
+    "2.7.5")
+        OOZIE_VERSION="4.3.0"
+        HADOOP_VERSION="2.7.5"
+        BUILD_ARGS="-Puber -P hadoop-2"
+    ;;
     "2.8.2")
         OOZIE_VERSION="4.3.0"
         HADOOP_VERSION="2.8.2"
         BUILD_ARGS="-Puber -P hadoop-2"
+    ;;
+    "3.0.1")
+        OOZIE_VERSION="5.0.0"
+        HADOOP_VERSION="3.0.1"
+        BUILD_ARGS="-Puber "
+
 esac
 
 echo "Install required packages"
@@ -56,6 +67,13 @@ if [ "${OOZIE_VERSION}" = "4.3.0" ]; then
         --subnode "/N:project/N:dependencies/N:dependency[last()]" -t elem -n scope -v compile pom.xml.tmp > pom.xml
     popd
 fi
+if [ "${OOZIE_VERSION}" = "5.0.0" ]; then
+    # see https://issues.apache.org/jira/browse/OOZIE-3219
+    patch -p0 < ./../tools/oozie_core.patch
+fi
+
+mv pom.xml pom.xml.tmp
+xmlstarlet ed -P -N N="http://maven.apache.org/POM/4.0.0" -u "/N:project/N:repositories/N:repository[N:url='http://repo1.maven.org/maven2']/N:url" -v "https://repo1.maven.org/maven2" pom.xml.tmp >pom.xml
 
 ./bin/mkdistro.sh assembly:single ${BUILD_ARGS} -Dhadoop.version=${HADOOP_VERSION} -DjavaVersion=1.8 -DtargetJavaVersion=1.8 -DskipTests
 mkdir -p ./../dist/oozie/
